from ..plugin import LocalBridgePlugin
from flask import Blueprint, request, jsonify, send_file
import logging
import os
import tempfile

class ScreenshotPlugin(LocalBridgePlugin):
    def __init__(self):
        super().__init__(
            name="screenshot",
            uri="local://screenshot",
            methods=["GET"],
            description="Take a screenshot of the current screen"
        )
        self.blueprint = Blueprint("screenshot", __name__)
        self.logger = logging.getLogger("LocalBridgeScreenshotPlugin")

    def register(self, app, config):
        @self.blueprint.route("/localbridge/screenshot", methods=["GET"])
        def take_screenshot():
            if not self._check_token(request, config.token):
                return jsonify({"error": "Unauthorized"}), 401
            try:
                # Use Pillow and pyautogui for cross-platform screenshot
                import pyautogui
                import datetime
                screenshot = pyautogui.screenshot()
                temp_dir = tempfile.gettempdir()
                filename = f"screenshot_{datetime.datetime.now().strftime('%Y%m%d_%H%M%S')}.png"
                file_path = os.path.join(temp_dir, filename)
                screenshot.save(file_path)
                self.logger.info(f"Screenshot taken: {file_path}")
                return send_file(file_path, mimetype="image/png", as_attachment=True)
            except Exception as e:
                self.logger.error(f"Failed to take screenshot: {e}")
                return jsonify({"error": str(e)}), 500

        app.register_blueprint(self.blueprint)

    def _check_token(self, req, token):
        return req.headers.get("X-LocalBridge-Agent-Token") == token
