from ..plugin import LocalBridgePlugin
from flask import Blueprint, request, jsonify, send_file
import logging
import tempfile
import os

class WebcamPlugin(LocalBridgePlugin):
    def __init__(self):
        super().__init__(
            name="webcam",
            uri="local://webcam",
            methods=["GET"],
            description="Capture an image from the webcam"
        )
        self.blueprint = Blueprint("webcam", __name__)
        self.logger = logging.getLogger("LocalBridgeWebcamPlugin")

    def register(self, app, config):
        @self.blueprint.route("/localbridge/webcam", methods=["GET"])
        def capture_webcam():
            if not self._check_token(request, config.token):
                return jsonify({"error": "Unauthorized"}), 401
            try:
                # Use OpenCV to capture a webcam image
                import cv2
                cap = cv2.VideoCapture(0)
                if not cap.isOpened():
                    self.logger.error("Webcam not available.")
                    return jsonify({"error": "Webcam not available"}), 500
                ret, frame = cap.read()
                cap.release()
                if not ret:
                    self.logger.error("Failed to capture image from webcam.")
                    return jsonify({"error": "Failed to capture image"}), 500
                temp_dir = tempfile.gettempdir()
                file_path = os.path.join(temp_dir, "webcam_capture.png")
                cv2.imwrite(file_path, frame)
                self.logger.info(f"Webcam image captured: {file_path}")
                return send_file(file_path, mimetype="image/png", as_attachment=True)
            except Exception as e:
                self.logger.error(f"Failed to capture webcam image: {e}")
                return jsonify({"error": str(e)}), 500

        app.register_blueprint(self.blueprint)

    def _check_token(self, req, token):
        return req.headers.get("X-LocalBridge-Agent-Token") == token
